@@ -59,6 +59,7 @@ class BaseLog:
             handler_dict[level]['when'] = when
             handler_dict[level]['backupCount'] = backup_count
             handler_dict[level]['interval'] = 1
+            handler_dict[level]['encoding'] = 'utf-8'
         loggers_dict = dict()
         loggers_dict[self.program_log_name] = dict()
         loggers_dict[self.journal_log_name] = dict()
@@ -76,16 +77,16 @@ class BaseLog:
     def program_model(self, log_level, message, extra=None):
         path_name, lineno, func_name, logger_module = self.get_current_location()
         data = {
-            "app_name": self.program_log_name,  # 服务编号
-            "logger": logger_module,  # 日志对象名
-            "HOSTNAME": self.host_name,  # 主机名
-            "log_time": self.date_log_time(),  # 时间
-            "level": log_level,  # 日志界别
-            "thread": threading.currentThread().ident,  # 线程编号
-            "code_message": message[:3000],  # 消息
-            "pathName": path_name,  # 打印日志位置
-            "lineNo": lineno,  # 打印日志行号
-            "funcName": func_name,  # 打印日志方法名
+            "app_name": str(self.program_log_name),  # 服务编号
+            "logger": str(logger_module),  # 日志对象名
+            "HOSTNAME": str(self.host_name),  # 主机名
+            "log_time": str(self.date_log_time()),  # 时间
+            "level": str(log_level),  # 日志界别
+            "thread": str(threading.currentThread().ident),  # 线程编号
+            "code_message": str(message[:3000]),  # 消息
+            "pathName": str(path_name),  # 打印日志位置
+            "lineNo": str(lineno),  # 打印日志行号
+            "funcName": str(func_name),  # 打印日志方法名
         }
         if isinstance(extra, dict):
             data.update(extra)
@@ -206,34 +207,34 @@ class BaseLog:
         if len(response_content) > 3000:
             response_content = response_content[:3000]
         data = {
-            "app_name": self.journal_log_name,  # 服务编号
-            "level": log_level,  # 日志界别
-            "logger": logger_module,  # 日志对象名
-            "log_time": self.date_log_time(),  # 时间
-            "transaction_id": transaction_id,
-            "dialog_type": dialog_type,
-            "address": request_url,
+            "app_name": str(self.journal_log_name),  # 服务编号
+            "level": str(log_level),  # 日志界别
+            "logger": str(logger_module),  # 日志对象名
+            "log_time": str(self.date_log_time()),  # 时间
+            "transaction_id": str(transaction_id),
+            "dialog_type": str(dialog_type),
+            "address": str(request_url),
             "fcode": f_code if dialog_type == 'in' else self.t_code,
             "tcode": self.t_code if dialog_type == 'in' else f_code,
             "method_code": str(method_code or ""),
             "http_method": str(http_method or ""),
             "request_time": request_time.strftime("%Y-%m-%d %H:%M:%S.%f")[:-3],
-            "request_headers": request_headers,
-            "request_payload": request_content,
-            "response_headers": response_headers,
-            "response_payload": response_content,
+            "request_headers": str(request_headers),
+            "request_payload": str(request_content),
+            "response_headers": str(response_headers),
+            "response_payload": str(response_content),
             "response_time": response_time.strftime("%Y-%m-%d %H:%M:%S.%f")[:-3],
             "response_code": str(response_code or ""),
-            "response_remark": remark,
+            "response_remark": str(remark),
             "http_status_code": str(http_status_code or ""),
-            "order_id": order_id,
-            "account_type": account_type,
-            "account_num": phone_num,
+            "order_id": str(order_id),
+            "account_type": str(account_type),
+            "account_num": str(phone_num),
             "province_code": "",
             "city_code": "",
             "key_type": "",
             "key_param": "",
-            "total_time": str(total_time),
+            "total_time": round(float(total_time), 2),
         }
         message = json.dumps(data, ensure_ascii=False)
         logging.getLogger(self.journal_log_name).info(message)
